#!/usr/bin/env python
# -*- coding: utf8 -*-

#-----------------------------------------
# This is a part of Collège 3D project.
# Author:       Pascal Peter
# Copyright:    (C) 2003-2016 Pascal Peter
# Licence:      GNU General Public Licence version 3
# Website:      http://pascal.peter.free.fr/
# Email:        pascal.peter at free.fr
#-----------------------------------------

"""
DESCRIPTION :
    Définition d'un client réseau gérant en parallèle l'émission
    et la réception des messages (utilisation de 2 THREADS).
    d'après Swinnen : http://inforef.be/swi/python.htm
"""

# importation des modules utiles :
from __future__ import print_function#, unicode_literals

import sys
import socket
#import logging

PYTHONVERSION = sys.version_info[0] * 10 + sys.version_info[1]

if PYTHONVERSION >= 30:
    import asyncoro3 as asyncoro
else:
    import asyncoro2 as asyncoro

import bge



def toSend(msg):
    if PYTHONVERSION >= 30:
        return bytes(msg, 'utf8')
    return msg

def client_recv(conn, coro=None):
    conn = asyncoro.AsyncSocket(conn)
    while True:
        line = yield conn.recv_msg()
        if not line:
            break
        line = line.decode('utf-8')
        print('RECV:', line)



# **************************************************
#       PROGRAMME PRINCIPAL
# **************************************************
def main(host, port):
    # Programme principal - Établissement de la connexion :
    mySocket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    try:
        mySocket.connect((host, port))
    except socket.error:
        print('CLIENT SOCKET ERROR (main)')
        return False
    print('CLIENT CONNECTED')

    asyncoro.Coro(client_recv, mySocket)
    # wrap it with asyncoro's synchronous socket so 'send_msg' can be
    # used
    conn = asyncoro.AsyncSocket(mySocket, blocking=True)

    if not('sent_message' in bge.logic.globalDict):
        bge.logic.globalDict['LAN']['sent_message'] = ''
    while True:
        try:
            sent_message = bge.logic.globalDict['LAN']['sent_message']
        except:
            sent_message = ''
            break
        if sent_message != '':
            bge.logic.globalDict['LAN']['sent_message'] = ''
            if sent_message.upper() == 'END':
                break
            sent_message = toSend(sent_message)
            print('SEND:', sent_message.decode('utf-8'))
            conn.send_msg(sent_message)
    conn.shutdown(socket.SHUT_WR)
    return True

